# Python Android TV Remote
Author:Tim Santor <tsantor@xstudios.agency>

## Overview
Simple package that allows you to mimic Android TV remote inputs via Python.


## Features
- TODO


## Installation
To install python-android-tv-remote, simply:

    pip install android-tv-remote

## Tips
Get IP address:
```
adb -s <DEVICE_ID> shell ip -f inet addr show wlan0
```


## Documentation
Documentation is available at TODO


## Issues
If you experience any issues, please create an [issue](https://bitbucket.org/tsantor/python-android-tv-remote/issues) on Bitbucket.


## Resources
- https://beeware.org/
- https://hackernoon.com/making-a-tv-remote-in-python-ef1dd5409524
- https://github.com/eslavnov/android-tv-remote
- https://github.com/simse/pymitv
